// Copyright 2012 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.api.ads.adwords.lib.utils;

import com.google.api.ads.common.lib.utils.Streams;

import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;

/**
 * {@link ReportWriter} that handles writing AWQL reports in the correct format.
 *
 * @author Kevin Winter
 */
public class AwqlWriter implements ReportWriter {

  private static final String REPORT_FORMATTER = "__rdquery=%s&__fmt=%s";

  private final String reportQuery;
  private final String format;

  /**
   * Constructs a ReportWriter for AWQL reports.
   *
   * @param reportQuery Query to report on.
   * @param format Download format.
   */
  public AwqlWriter(String reportQuery, String format) {
    this.reportQuery = reportQuery;
    this.format = format;
  }

  public void write(OutputStream outputStream) throws IOException {
    Streams.write(String.format(
        REPORT_FORMATTER,
        URLEncoder.encode(reportQuery, "UTF-8"),
        URLEncoder.encode(format, "UTF-8")), outputStream);
  }

  public String getReportParameters() {
    return reportQuery + " -> " + format;
  }
}
